#
# spec file for package libharu
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define relver 2_4
%define lname   libhpdf%{relver}
Name:           libharu
Version:        2.4.4
Release:        1.3
Summary:        Library for generating PDF files
License:        Zlib
Group:          Productivity/Office/Other
URL:            http://libharu.org
Source0:        https://github.com/libharu/libharu/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  libpng-devel
BuildRequires:  zlib-devel

%description
libHaru is a library for generating PDF files.
It supports the following features:
- Generating PDF files with lines, text, images.
- Outline, text annotation, link annotation.
- Compressing document with deflate-decode.
- Embedding PNG, JPEG images.
- Embedding Type1 font and TrueType font.
- Creating encrypted PDF files.
- Using various character sets (ISO8859-1~16, MSCP1250~8, KOI8-R).
- CJK fonts and encodings.

%package -n %{lname}
Summary:        Library for generating PDF files
Group:          System/Libraries

%description -n %{lname}
libHaru is a library for generating PDF files.
It supports the following features:
- Generating PDF files with lines, text, images.
- Outline, text annotation, link annotation.
- Compressing document with deflate-decode.
- Embedding PNG, JPEG images.
- Embedding Type1 font and TrueType font.
- Creating encrypted PDF files.
- Using various character sets (ISO8859-1~16, MSCP1250~8, KOI8-R).
- CJK fonts and encodings.

%package        devel
Summary:        Development files for libharu
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       libpng-devel
Requires:       zlib-devel
Conflicts:      libhpdf2_4_2

%description    devel
This package contains libraries and header files for developing
applications that use %{name}.

%prep
%autosetup -p1

%build
%cmake \
  -DBUILD_SHARED_LIBS:BOOL=ON \
  %{nil}
%cmake_build

%install
%cmake_install

%fdupes %{buildroot}%{_datadir}/%{name}/

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license LICENSE
%doc README.md
%{_libdir}/libhpdf.so.*

%files devel
%{_libdir}/libhpdf.so
%{_includedir}/*.h
%{_datadir}/%{name}/

%changelog
* Tue Sep 19 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.4:
  * Add copy hpdf_namedict.h at install [gh#libharu/libharu#265].
  * Added page boundary support [gh#libharu/libharu#274].
  * Fixed glyph index to be 16 bit unsigned instead of signed
    [gh#libharu/libharu#277].
  * Bug fixes [gh#libharu/libharu#255].
  * Shared library has an SOVERSION now.
  * Fixed HPDF_FToA for small values.
- Drop libharu-so-versioning.patch: fixed upstream.
* Thu Jun 29 2023 Atri Bhattacharya <badshah400@gmail.com>
- Move Conflicts against libhpdf2_4_2 to devel package.
* Mon Jun 26 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add libharu-so-versioning.patch -- Add correct versioning to
  shared object libhpdf.so [gh#libharu/libharu#284]; patch sent
  upstream.
- Drop so version setting snippet from specfile in light of
  above patch.
- Re-name shared library as libhpdf2; add Conflicts against
  previously named libhpdf2_4_2, which violated the SLPP.
- Use fdupes to clean up a duplicate.
* Sat Oct 15 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 2.4.3:
  * Add static hpdf_version.h header
  * hpdf_version.h included again
  * File attachment issue resolved
  * Renamed *_LIBZ defines to _*ZLIB, enables compression of
    PDF files again.
- Clean up spec file
- Add SOVERSION to library, remove rpmlintrc
* Mon Sep 12 2022 Dirk Müller <dmueller@suse.com>
- update to 2.4.2:
  * Fixed library name
  * Set correct version number
  * Add support for free-form triangle shading objects.
  * Fix config constant to match use in hpdf_mmgr.c
  * Improve small number writing in HPDF_FToA.
  * Fix missing /CapHeight key in font definition
  * Change HPDF_Page_CreateXObjectFromImage zoom parameter type to HPDF…
  * Fix another case of png files with background mask save uncompressed
  * Avoid issue with libtiff duplicate symbols
  * Reajust bit_depth of png image after striping depth from 16 to 8.
  * Fixed typo in Japanese font name: Mincyo -> Mincho
  * Fix various typos
  * hpdf.h: add missing HPDF_Boolean typedef
  * Moved to a CMake only build environment.
  * Fix bad unicode in comment
  * Fix various typos
- package license
- drop upstream patches: libharu-cmake.patch, libharu-link-libm.patch
* Fri Dec 29 2017 jengelh@inai.de
- Trim filler words from descriptions.
  Drop double "support" word from feature list.
* Wed Dec 27 2017 badshah400@gmail.com
- Update to version 2.3.0:
  * Added support for 3dMeasures of subtype PD3 and 3DC,
    projection annotations, ExData and javascript attached to a
    U3D model.
  * Added support for 1- and 2-byte UTF8 codes.
  * Added full PDF/A1-b support.
  * Added support for CCITT compression for B/W images.
  * Add support for TwoPageLeft and TwoPageRight layouts.
  * Const-ified arrays used in the sources.
  * Fixed build with libpng 1.5.0
  * Fixed bug in HPDF_GetContents() - isize variable was not
    initialized.
  * Fixed possible endless loop in PNG handling code.
  * Fixed several issues based on the warnings generated by
    clang-analyzer.
  * Fixed quite a number of warnings.
  * Added 'd' postfix to debug build, fixed wrong filename.
  * Fixed HPDF_Text_Rect() not to split words in some obscure
    cases.
- Switch to cmake-based build; add BuildRequires: cmake.
- Drop patches incorporated upstream:
  * libharu-2.2.1-png15.patch
  * libharu-2.2.1-png16.patch
- Add libharu-cmake.patch to fix installation locations when
  using cmake-based build.
- Add libharu-link-libm.patch to add -libm to linker flag when
  building using cmake.
- Add libharu-cmake.patch to fix install locations when building
  using cmake.
* Mon Dec  7 2015 jengelh@inai.de
- Correct shlib package name; adjust RPM groups
* Tue Apr  9 2013 pgajdos@suse.com
- builds also with libpng16
  * png16.patch
* Sun Jan 20 2013 dmitry_r@opensuse.org
- Replace source archive
* Thu Jan 17 2013 dmitry_r@opensuse.org
- Fix devel package requirements
* Tue Jan 15 2013 dmitry_r@opensuse.org
- spec file cleanup
- Rename library package according to shared library packaging policy
- Fix build with libpng 1.5
  * libharu-2.2.1-png15.patch
* Wed Jul  9 2008 otto.dassau@gmx.de
- created spec file for opensuse BuildService
